@@ -1,4 +1,4 @@
-jaatha_log_class <- R6Class("jaatha_log", 
+jaatha_log_class <- R6::R6Class("jaatha_log", 
   private = list(
     estimates = NULL,
     final_estimates = NULL,
@@ -15,7 +15,6 @@ jaatha_log_class <- R6Class("jaatha_log",
   ),
   public = list(
     initialize = function(model, data, reps, max_steps, verbose = TRUE) {
-      
       par_number <- model$get_par_number()
       par_names <- model$get_par_ranges()$get_par_names()
       private$estimates <- lapply(1:reps, function(i) {
