@@ -1,5 +1,4 @@
-#' @importFrom R6 R6Class
-stat_cube_class <- R6Class("stat_cube", inherit = stat_basic_class,
+stat_cube_class <- R6::R6Class("stat_cube", inherit = stat_basic_class,
   lock_objects = FALSE, lock_class = TRUE,
   private = list(
     break_values = numeric(),
